Index: trunk/psLib/src/fits/psFitsFloat.h
===================================================================
--- trunk/psLib/src/fits/psFitsFloat.h	(revision 15630)
+++ trunk/psLib/src/fits/psFitsFloat.h	(revision 16108)
@@ -12,13 +12,13 @@
 } psFitsFloat;
 
-/// Convert an image to custom floating-point in preparation for writing as FITS
-psImage *psFitsFloatImageWrite(const psImage *image, ///< Image to convert
+/// Convert an image to custom floating-point (the disk representation) in preparation for writing as FITS
+psImage *psFitsFloatImageToDisk(const psImage *image, ///< Image to convert
                                psFitsFloat type ///< Custom floating point type
     );
 
-/// Convert the custom floating-point image to a floating-point image
-psImage *psFitsFloatImageRead(psImage *out, ///< Output image, or NULL
-                              const psImage *in, ///< Image to convert
-                              psFitsFloat type ///< Custom floating point type
+/// Convert the custom floating-point image (the disk representation) to a normal floating-point image
+psImage *psFitsFloatImageFromDisk(psImage *out, ///< Output image, or NULL
+                                  const psImage *in, ///< Image to convert
+                                  psFitsFloat type ///< Custom floating point type
     );
 
